# HiveNetPipeline

HiveNetPipeline is the encapsulation of the pipeline processing framework provided by HiveNetAssemble, which realizes the management and implementation of simple pipeline mode processing flow.

docs: https://hivenetassemble.readthedocs.io/zh_CN/latest/
